@@ -25,7 +25,7 @@ def vartype(func: macal.FunctionDefinition, scope: macal.Scope, filename: str) -
     macal.ValidateFunctionArguments(func, scope, filename)
     var = scope.GetVariable("var")
     val = var.GetValue()
-    scope.SetReturnValue(val.getType())
+    scope.SetReturnValue(val.GetType())
     rvar = scope.GetFunctionReturnVariable()
     rvar.Value.Type = macal.VariableTypes.Type
 
@@ -61,7 +61,7 @@ def isString(func: macal.FunctionDefinition, scope: macal.Scope, filename: str)
     macal.ValidateFunctionArguments(func, scope, filename)
     var = scope.GetVariable("var")
     val = var.GetValue()
-    result = val.getType() == macal.VariableTypes.String
+    result = val.GetType() == macal.VariableTypes.String
     scope.SetReturnValue(result)
 
 
@@ -70,7 +70,7 @@ def isInt(func: macal.FunctionDefinition, scope: macal.Scope, filename: str) ->
     macal.ValidateFunctionArguments(func, scope, filename)
     var = scope.GetVariable("var")
     val = var.GetValue()
-    result = val.getType() == macal.VariableTypes.Int    
+    result = val.GetType() == macal.VariableTypes.Int    
     scope.SetReturnValue(result)
 
 
@@ -79,7 +79,7 @@ def isFloat(func: macal.FunctionDefinition, scope: macal.Scope, filename: str) -
     macal.ValidateFunctionArguments(func, scope, filename)
     var = scope.GetVariable("var")
     val = var.GetValue()
-    result = val.getType() == macal.VariableTypes.Float
+    result = val.GetType() == macal.VariableTypes.Float
     scope.SetReturnValue(result)
 
 
@@ -88,7 +88,7 @@ def isBool(func: macal.FunctionDefinition, scope: macal.Scope, filename: str) ->
     macal.ValidateFunctionArguments(func, scope, filename)
     var = scope.GetVariable("var")
     val = var.GetValue()
-    result = val.getType() == macal.VariableTypes.Bool
+    result = val.GetType() == macal.VariableTypes.Bool
     scope.SetReturnValue(result)
 
 
@@ -97,7 +97,7 @@ def isRecord(func: macal.FunctionDefinition, scope: macal.Scope, filename: str)
     macal.ValidateFunctionArguments(func, scope, filename)
     var = scope.GetVariable("var")
     val = var.GetValue()
-    result = val.getType() == macal.VariableTypes.Record
+    result = val.GetType() == macal.VariableTypes.Record
     scope.SetReturnValue(result)
 
 
@@ -106,7 +106,7 @@ def isArray(func: macal.FunctionDefinition, scope: macal.Scope, filename: str) -
     macal.ValidateFunctionArguments(func, scope, filename)
     var = scope.GetVariable("var")
     val = var.GetValue()
-    result = val.getType() == macal.VariableTypes.Array
+    result = val.GetType() == macal.VariableTypes.Array
     scope.SetReturnValue(result)
 
 
@@ -115,7 +115,7 @@ def isFunction(func: macal.FunctionDefinition, scope: macal.Scope, filename: str
     macal.ValidateFunctionArguments(func, scope, filename)
     var = scope.GetVariable("var")
     val = var.GetValue()
-    result = val.getType() == macal.VariableTypes.Function
+    result = val.GetType() == macal.VariableTypes.Function
     scope.SetReturnValue(result)
 
 
@@ -124,7 +124,7 @@ def isNil(func: macal.FunctionDefinition, scope: macal.Scope, filename: str) ->
     macal.ValidateFunctionArguments(func, scope, filename)
     var = scope.GetVariable("var")
     val = var.GetValue()
-    result = val.getType() == macal.VariableTypes.Nil
+    result = val.GetType() == macal.VariableTypes.Nil
     scope.SetReturnValue(result)
 
 
@@ -147,8 +147,8 @@ def items(func: macal.FunctionDefinition, scope: macal.Scope, filename: str) ->
     macal.ValidateFunctionArguments(func, scope, filename)
     var = scope.GetVariable("var")
     val = var.GetValue()
-    rec = val.getValue()
-    t = val.getType()
+    rec = val.GetValue()
+    t = val.GetType()
     if t != macal.VariableTypes.Record:
         raise macal.RuntimeError(f'Invalid variable type ({t}) "record" type is required.', val.Token.Location, filename)
     pv = [{key: value} for key, value in rec.items()]
@@ -161,8 +161,8 @@ def recordItemKey(func: macal.FunctionDefinition, scope: macal.Scope, filename:
     macal.ValidateFunctionArguments(func, scope, filename)
     var = scope.GetVariable("var")
     val = var.GetValue()
-    rec = val.getValue()
-    t = val.getType()
+    rec = val.GetValue()
+    t = val.GetType()
     if t != macal.VariableTypes.Record:
         raise macal.RuntimeError(f'Invalid variable type ({t}) "record" type is required.', val.Token.Location, filename)
     for k, v in rec.items(): #there are different ways, but this is by far the most simple and safe way to do it.
@@ -176,8 +176,8 @@ def recordKeys(func: macal.FunctionDefinition, scope: macal.Scope, filename: str
     macal.ValidateFunctionArguments(func, scope, filename)
     var = scope.GetVariable("var")
     val = var.GetValue()
-    rec = val.getValue()
-    t = val.getType()
+    rec = val.GetValue()
+    t = val.GetType()
     if t != macal.VariableTypes.Record:
         raise macal.RuntimeError(f'Invalid variable type ({t}) "record" type is required.', val.Token.Location, filename)
     val = [k for k in rec.keys()]
@@ -190,8 +190,8 @@ def recordItemValue(func: macal.FunctionDefinition, scope: macal.Scope, filename
     macal.ValidateFunctionArguments(func, scope, filename)
     var = scope.GetVariable("var")
     val = var.GetValue()
-    rec = val.getValue()
-    t = val.getType()
+    rec = val.GetValue()
+    t = val.GetType()
     if t != macal.VariableTypes.Record:
         raise macal.RuntimeError(f'Invalid variable type ({t}) "record" type is required.', val.Token.Location, filename)
     for k, v in rec.items(): #there are different ways, but this is by far the most simple and safe way to do it.
@@ -205,8 +205,8 @@ def recordValues(func: macal.FunctionDefinition, scope: macal.Scope, filename: s
     macal.ValidateFunctionArguments(func, scope, filename)
     var = scope.GetVariable("var")    
     val = var.GetValue()
-    rec = val.getValue()
-    t = val.getType()
+    rec = val.GetValue()
+    t = val.GetType()
     if t != macal.VariableTypes.Record:
         raise macal.RuntimeError(f'Invalid variable type ({t}) "record" type is required.', val.Token.Location, filename)
     val = [v for v in rec.values()]
