@@ -133,22 +133,22 @@ class Interpreter:
 
 
     def InterpretAssignToIndexedVar(self, var: variable.Variable, idx: ast_expr.Expr, value: value_item.ValueItem, scope: mscope.Scope):
+        if var.Value.Type not in [types.VariableTypes.Array, types.VariableTypes.Record, types.VariableTypes.String]:
+            raise exceptions.RuntimeError(f'Type error, index not supported on {var.Value.Type}. ({var.Name}).', idx.Token.Location, self.filename)    
+        val = var.Value
         expr = idx
         vind = []
         while expr.ExprType != types.ExprTypes.VariableIndexStart:
             vind.insert(0, expr.Right)
             expr = expr.Left
-        val = var.Value
-        if val.Type not in [types.VariableTypes.Array, types.VariableTypes.Record, types.VariableTypes.String]:
-            raise exceptions.RuntimeError(f'Type error, index not supported on {val.Type}', ind.Token.Location, self.filename)    
         lng = len(vind)
         cnt = 0
         for ind in vind:
             if val.Type not in [types.VariableTypes.Array, types.VariableTypes.Record, types.VariableTypes.String]:
-                raise exceptions.RuntimeError(f'Type error, index not supported on {val.Type}', ind.Token.Location, self.filename)    
+                raise exceptions.RuntimeError(f'Type error, index not supported on {val.Type}. ({var.Name})', ind.Token.Location, self.filename)    
             if ind.ExprType == types.ExprTypes.NewArrayIndex:
                 if val.Type != types.VariableTypes.Array:
-                    raise exceptions.RuntimeError(f'Type error, append not supported on {val.Type}', ind.Token.Location, self.filename)    
+                    raise exceptions.RuntimeError(f'Type error, append not supported on {val.Type}. ({var.Name})', ind.Token.Location, self.filename)
                 val.Value.append(value)
                 return
             i = self.InterpretExpression(ind, scope)
@@ -166,6 +166,7 @@ class Interpreter:
                     raise exceptions.RuntimeError(f'Index ({i.Value}) is out of range. ({var.Name})', ind.Token.Location, self.filename)
             val = val.Value[i.Value]
             cnt+=1
+
         if expr.Right is not None and expr.Right.ExprType == types.ExprTypes.NewArrayIndex:
             if val.Type != types.VariableTypes.Array:
                 raise exceptions.RuntimeError(f'Type error, append not supported on {val.Type}', ind.Token.Location, self.filename)    
@@ -329,14 +330,15 @@ class Interpreter:
 
 
     def InterpretIndexedVariableExpression(self, var: variable.Variable, idx: ast_expr.Expr, scope: mscope.Scope)-> value_item.ValueItem:
+        if var.Value.Type not in [types.VariableTypes.Array, types.VariableTypes.Record, types.VariableTypes.String]:
+            raise exceptions.RuntimeError(f'Type error, index not supported on {var.Value.Type}. ({var.Name}).', idx.Token.Location, self.filename)    
+        val = var.Value
         expr = idx
         vind = []
         while expr.ExprType != types.ExprTypes.VariableIndexStart:
             vind.insert(0, expr.Right)
             expr = expr.Left
-        val = var.Value
-        if val.Type not in [types.VariableTypes.Array, types.VariableTypes.Record, types.VariableTypes.String]:
-            raise exceptions.RuntimeError(f'Type error, index not supported on {val.Type}. ({var.Name}).', idx.Token.Location, self.filename)    
+        
         for ind in vind:
             if val.Type not in [types.VariableTypes.Array, types.VariableTypes.Record, types.VariableTypes.String]:
                 raise exceptions.RuntimeError(f'Type error, index not supported on {val.Type}. ({var.Name}).', ind.Token.Location, self.filename)
