@@ -229,9 +229,12 @@ class Parser:
             (index, match) = self.Match(index, types.LexTokenTypes.InterpolationEnd, '$')
             while not match:
                 (index, right) = self.Expression(index, inFnDef) # This is very tricky, going all the way back up to expression.
-                expr = ast_expr.Expr(right).Binary(expr, operator, right)
+                expr = ast_expr.Expr(right.Token).Binary(expr, operator, right)
                 (index, match) = self.Match(index, types.LexTokenTypes.InterpolationEnd, '$')
-            return (index, ast_expr.Expr(left).InterpolationPart(expr))
+            result = ast_expr.Expr(left).InterpolationPart(expr)
+            if result.Right.ExprType != types.ExprTypes.Binary:
+                raise exceptions.ParserError("Interpolation string doesn't contain interpolation.", expr.Token.Location, self.filename)
+            return (index, result)
         (index, expr) = self.Unary(index, inFnDef)
         return (index, expr)
 
